@@ -1,7 +1,8 @@
 context("test-update")
 
 test_that("empty-functions works", {
-  # skip_on_cran()
+  skip_on_cran()
+
   x <- ukc_last_update()
   expect_true(is.character(x$date))
 
